LinchPin 1.0.1 RELEASE NOTES
============================

LinchPin 1.0.1 is a bugfix release

Bug Fixes
----------

* `linchpin destroy duffy error after 1.0 upgrade <https://github.com/CentOS-PaaS-SIG/linchpin/issues/263>`_
* `1.0 error with linchpin init/linchpin up <https://github.com/CentOS-PaaS-SIG/linchpin/issues/264>`_
* `linchpin rise/up error since upgrade to 1.0.0 <https://github.com/CentOS-PaaS-SIG/linchpin/issues/267>`_
* `libvirt provisioning does not work on centos/rhel machines <https://github.com/CentOS-PaaS-SIG/linchpin/issues/269>`_
* `Unable to get topology file to pass schema validation <https://github.com/CentOS-PaaS-SIG/linchpin/issues/271>`_
* `Authorization failing with linchpin 1.0.0 <https://github.com/CentOS-PaaS-SIG/linchpin/issues/274>`_
* `Inventory generation fails as resource outputs are not generated <https://github.com/CentOS-PaaS-SIG/linchpin/issues/275>`_

Enhancements
------------

* `Make a default path for credentials <https://github.com/CentOS-PaaS-SIG/linchpin/issues/280>`_



